package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````D"(``#0````PP0```````#0`(``,
M`"@`&P`:``8````T````-````#0```"``0``@`$```0````$`````P```+0!
M``"T`0``M`$``!,````3````!`````$````!````````````````````K!$`
M`*P1```$`````!````$`````(````"`````@``#,,```S#````4`````$```
M`0````!@````8````&```&1.``!D3@``!``````0```!````V+T``-B]``#8
MO0``0`(``%0"```&`````!````(```#@O0``X+T``."]```(`0``"`$```8`
M```$````!````,@!``#(`0``R`$``&P```!L````!`````0```!3Y71D[`$`
M`.P!``#L`0``*````"@````$````!````%#E=&1,H```3*```$R@```4`0``
M%`$```0````$````4>5T9```````````````````````````!@```!````!2
MY71DV+T``-B]``#8O0``*`(``"@"```$`````0```"]L:6(O;&0M;&EN=7@N
M<V\N,@``!````!0````#````1TY5`)':1:)L;OY(5QS0S;J_U$FCXNI*!```
M`!@````%````1TY5``$``<`$`````0````(``<`$``````````0````0````
M`0```$=.50``````!`````0`````````+P```$0````(````"``````0$`0E
M0`2`*`$`!:"&`(2``0``"R@$"#B`$D&*```(``````````!$````````````
M``!%````````````````````1P```$@`````````20````````!*````````
M`$L```````````````````!,`````````$T``````````````$\```!0````
M`````%$``````````````%,`````````5````%4``````````````%8```!8
M````60```%H```!;````7````````````````````%T```!K"4/6+L6;MF_%
MWQ^S`8MO0_K7AVM_FGRM2^/`6>CM[.-'Q@$,.I<+P^4_+"'_Y`Y_J9R;X*<"
M"KOCDGS59-1\S]Y'+?NA;&!J&IY0H^#[23-BV^T5C"7,9Z_,9D-%U>R)!W#3
MV7%8'`````````````````````"M`@`````````````2````%P(`````````
M````$@```!$"`````````````!(````_`0`````````````2````@```````
M````````$@```+```````````````!(```#3`0`````````````2````/0(`
M````````````$@```'P!`````````````!(````!```````````````@````
M)P(`````````````$@```(("`````````````!(```#0`@`````````````2
M````IP``````````````$@```%,``````````````!(```"[````````````
M```2````V@$`````````````$@````4"`````````````!(````0````````
M```````@````'P$`````````````$@```$0!`````````````!(```"8`@``
M```````````2````+```````````````(````$P"`````````````!(```")
M`@`````````````2````CP$`````````````$@````P!`````````````!8`
M``"7```````````````2````;P``````````````$@```&L!````````````
M`!(```#8```````````````2````N0$`````````````$@```&4"````````
M`````!$```"?`@`````````````2````^`$`````````````$@```.(!````
M`````````!(```"/`P`````````````2````R0``````````````$@```)$"
M`````````````!(```#(`@`````````````1````R@$`````````````$@``
M`.<``````````````!(````*`@`````````````2````50$`````````````
M$@```/4``````````````!(```!C```````````````2````X@(`````````
M````$@```/\!`````````````!(```#Q`0`````````````2````2P(`````
M````````$@```!X"`````````````!(```#I`0`````````````2````*@$`
M````````````$@```$D!`````````````!(````O`@`````````````2````
MQ@(`````````````$0```&P"`````````````!(```"^`@`````````````2
M````1@``````````````$0```(P``````````````!(```!<`0``````````
M```2````PP$`````````````$@```%,"`````````````!(```"Q`0``````
M```````2````I@(`````````````$@```',"`````````````"(```"L`0``
M```````````2````I`,```#`````````$``7``@#``"`+```!0```!(`#@"8
M`P``8#\``-$````2``X`0P,``(`T``!A````$@`.`+$#``"`3```UP$``!(`
M#@!@`@``0"```$@"```2``X`G0$```1@```$````$0`0`"8#````8```!```
M`!$`$``9`P``P"X``#@````2``X`I@,```#`````````(``7`+P#``!P*P``
M-````!(`#@`$!```D"P``"<"```2``X`?0,``/`T```M````$@`.`%$#``"P
M*P``S0```!(`#@#9`P``+,`````````0`!@`+0,``$`]```>`@``$@`.`-X#
M```@-@``'P<``!(`#@#R`P``(#4``/D````2``X`<P,``&!.```0`@``$@`.
M`!L$``"`,```_`,``!(`#@"J`P``D"(``"P````2``X`T`,``#!,``!0````
M$@`.`&<#````+P``=`$``!(`#@#K`P``&,`````````0`!<`$00``!3````$
M````$0`7`,0#```8P````````!``&```7U]G;6]N7W-T87)T7U\`7TE435]D
M97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B
M;&4`4$Q?9&]?=6YD=6UP`%!E<FQ?9W9?9F5T8VAP=@!097)L7VUG7W-E=`!0
M97)L7V%T9F]R:U]L;V-K`%!E<FQ?9V5T7W-V`%!E<FQ?;F5W6%,`8F]O=%]$
M>6YA3&]A9&5R`'!E<FQ?<G5N`'!E<FQ?<&%R<V4`4&5R;%]S=E]S971P=@!0
M97)L7W-V7W-E='!V;@!P97)L7V-O;G-T<G5C=`!P97)L7V1E<W1R=6-T`%!E
M<FQ?8W)O86M?;65M;W)Y7W=R87``4$Q?8W5R<F5N=%]C;VYT97AT`'!E<FQ?
M86QL;V,`4&5R;%]C<F]A:U]N;V-O;G1E>'0`<&5R;%]F<F5E`%!E<FQ?<V%F
M97-Y<VUA;&QO8P!097)L7W-Y<U]I;FET,P!097)L7VYE=UA37V9L86=S`%!E
M<FQ?871F;W)K7W5N;&]C:P!097)L7W-Y<U]T97)M`%])3U]S=&1I;E]U<V5D
M`&5X:70`;'-E96LV-`!R96%D9&ER-C0`<W1R9'5P`&-L;W-E9&ER`&]P96XV
M-`!S=')R8VAR`'5N;&EN:P!M96UM;W9E`'-T<G1O:P!S=')L96X`<FUD:7(`
M<F5A9`!S=')S='(`;6MD:7(`9V5T<&ED`')E861L:6YK`')E86QL;V,`7U]S
M<')I;G1F7V-H:P!?7V9P<FEN=&9?8VAK`&QS=&%T-C0`7U]L:6)C7W-T87)T
M7VUA:6X`<W1D97)R`&UE;6-H<@!?7V-X85]F:6YA;&EZ90!S=')C:'(`;W!E
M;F1I<@!G971U:60`86-C97-S`&UE;6-P>0!S=')C;7``7U]E<G)N;U]L;V-A
M=&EO;@!S=')N8VUP`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T
M86-K7V-H:U]F86EL`&QI8G!E<FPN<V\`;&EB8RYS;RXV`'!A<E]C=7)R96YT
M7V5X96,`<&%R7V)A<V5N86UE`%]F<%]H=P!84U]);G1E<FYA;'-?4$%27T)/
M3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I
M<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A
M<E]C;&5A;G5P`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN:70`7U]B
M<W-?<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A
M<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7VEN
M:71?96YV`$=,24)#7S(N,2XS`$=,24)#7S(N,S0`1TQ)0D-?,BXT`$=,24)#
M7S(N,@!'3$E"0U\R+C,S`$=,24)#7S(N,RXR`$=,24)#7S(N,RXT`$=,24)#
M7S(N,0!'3$E"0U\R+C``+W5S<B]L:6(O<&5R;#4O-2XS-B]C;W)E7W!E<FPO
M0T]210`````"``(``@`!``$``0`#``0``0`!``(``@`%``$``0`!``(``@`!
M``$``@`"``$`!@`"``$``0`!``$``0`!``<``@`"``(``@`"``$``@`"``(`
M`0`"``(``0`!``@``@`"``8``@`"``$``0`$``(``@`"``$``0`!``(`"0`#
M``(`"@`"``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0````$`"0#^`@``$`````````!S'VD)```*`"@$```0
M````M)&6!@``"0`T!```$````!1I:0T```@`/P0``!`````2:6D-```'`$D$
M```0````LY&6!@``!@!3!```$````'(9:0D```4`7@0``!````!T&6D)```$
M`&H$```0````$6EI#0```P!V!```$````!!I:0T```(`@`0```````#8O0``
M"````-R]```(````_+\```@````$P```"````!3````(````^+X```8!``#\
MO@``!@(```"_```&`P``!+\```8$```(OP``!@4```R_```&!@``$+\```8'
M```4OP``!@@``!B_```&"0``'+\```8*```@OP``!@L``"2_```&#```*+\`
M``8-```LOP``!@X``#"_```&#P``-+\```80```XOP``!A$``#R_```&$@``
M0+\```83``!$OP``!A0``$B_```&%0``3+\```86``!0OP``!A<``%2_```&
M&```6+\```89``!<OP``!AH``&"_```.&P``9+\```8<``!HOP``!AT``&R_
M```&'@``<+\```8?``!TOP``!B```'B_```&(0``?+\```8B``"`OP``!B,`
M`(2_```&)```B+\```8E``",OP``!B8``)"_```&)P``E+\```8H``"8OP``
M!BD``)R_```&*@``H+\```8K``"DOP``!BP``*B_```&+0``K+\```8N``"P
MOP``!B\``+2_```&,```N+\```8Q``"\OP``!C(``,"_```&,P``Q+\```8T
M``#(OP``!C4``,R_```&-@``T+\```8W``#4OP``!CD``-B_```&.@``W+\`
M``8[``#@OP``!CP``.2_```&/0``Z+\```8^``#LOP``!D```/"_```&00``
M]+\```9"``#XOP``!D,``/2^```'/P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!3@^P(Z+<"``"!P]^>``"+@S0```"%P'0"_]"#Q`A;P_^S!````/^C"```
M``````#_HPP```!H`````.G@____C4PD!(/D\/]Q_%6)Y5>)SU93Z&D"``"!
MPY&>``!1@^PLBT$$B474BT$(B4709:$4````B47D,<"-1=!0C4744%'_D_P`
M``"+@S````"#Q`Q04/^S@````&?HTB\``(N#]````(/$$(`X``^$)0$``(N#
M>````&6+`("(F@(```.+!XUP`X/`!(EUS#W___\_#X>&`0``@^P,P>`"4/^3
MY````(MUU(L_B<&)@SP!``"+!H/$$(D!C8/?HO__B4$$BX,L`0``B4$(C8/B
MHO__B4$,@_\!#XY3`0``B4W(C48$C5$0C32^C;0F`````&:0BPB#P`2#P@2)
M2OPYQG7QBTW(@\<#@^P,C8,H;/__QP2Y`````&H`4?]US%#_LT`!``#_DR0`
M``")QH/$((7`#X26````@^P,_[-``0``C7W@_Y.T````B?J-@[^A___H+`(`
M`(/$$(7`#X2%````@^P,_[-``0``_Y,<````@\00_Y-T````BT7D92L%%```
M``^%O````(UE\(GP65M>7UV-8?S#_Y-<````B8-``0``A<`/A(\```"#[`Q0
M_Y.(````BX-X````98L0@\00QH)#!@```.FK_O__@^P,_[-``0``_Y-$````
MB<:#Q!#I4?___XN#.`$``(7`=!&#[`Q0Z"D=``"#Q!#I8/___XGZC8-TH?__
MZ'0!``")@S@!``"%P`^$1?___^O2BT7D92L%%````'4;_Y/`````OP0```#I
MS?[__X/L#&H!_Y,0`0``Z!@N``!FD&:09I!FD#'M7HGA@^3P4%12Z!@```"!
MPTB<``!J`&H`45;_LQ0!``#H>?W___2+'"3#9I!FD(L<),-FD&:09I!FD&:0
M9I#HX````('"$YP``(V*,`$``(V",`$``#G(=!V+@E@```"%P'0358GE@^P4
M4?_0@\00R<.-="8`D,.-M"8`````Z*````"!PM.;``!5B>53C8HP`0``C8(P
M`0``@^P$*<B)P\'H'\'[`@'8T?AT%(N2:````(72=`J#[`A04?_2@\00BUW\
MR<.-M"8`````9I!5B>53Z%?___^!PW^;``"#[`2`NS`!````=2B+@PP!``"%
MP'02@^P,_[,<`0``_Y,,`0``@\00Z#3____&@S`!```!BUW\R<.-M"8`````
MD.E;____BQ0DPV:09I!FD)!5Z'<<``"!Q2*;``!75E.#[!R)5"0(A<`/A+(`
M``")P8N%K````(L0A=(/A*`````/M@&$P'0$/#UU53'_BQJ%VW0]B50D#(G8
MB=.)3"0$B<:-M"8`````@^P$5_]T)`Q6_Y7P````@\00A<!U!H`\/CUT-(MS
M!(/#!(7V==J)\X/$'(G86UY?7<.-M@````")SP^V1P&#QP&$P'0$/#UU\2G/
MZYB-=@"+5"0,B?")WHG#BT0D""G6C5P[`<'^`HDP@\0<B=A;7E]=PXUT)@"0
M@\0<,=N)V%M>7UW#C70F`%;HCQL``('&0IH``%.)PX/L?&6A%````(E$)'0Q
MP(U$)!104_^6U````(/$$(7`=3>+5"0<@>(`\```@?H`0```=`B!^@"@``!U
M'X/L"&H"4_^69````(/$$(7`#Y3`#[;`ZP:-="8`,<"+5"1L92L5%````'4&
M@\1T6U[#Z'XK``"-M"8`````C;0F`````%575NC]&@``@<:PF0``4XG#@>R,
M````9:$4````B40D?#'`A=MT!8`[`'4DBT0D?&4K!10````/A3P!``"!Q(P`
M``!;7E]=PXVT)@````"0@^P,4_^6<````(G'@\00A<!TR8/L#%?_EHP```"#
MQ!"%P`^$N````(!X$RZ-4!-U#X!Z`0!TW(VT)@````!FD(!X$RX/A+8```")
M5"0,@^P,4_^6F````(M4)!R)Q8D4)(E4)!S_EI@```"-1`4"B00D_Y:\````
MB<58C88@H?__6HM4)!124U!J_VH!5?^6Z````(/$&(U$)"105?^6;````(/$
M$(/X_W00BT0D+"4`\```/0!```!T98/L#%7_EIP```"#Q!"#[`Q5_Y9@````
M@\00Z3G___^-M@````"#[`Q7_Y:P````B1PD_Y;,````@\00Z>'^__^-="8`
MD(!Z`2X/A4#___^`>@(`#X3__O__Z3'___^-M"8`````B>CHB?[__^N?Z/(I
M``!FD%575E.-G"0``/__@>P`$```@PPD`#G<=?*#["SH[_O__X'#%Y@``(E$
M)`2)QV6A%````(F$)!P``0`QP&H":@!J`%?_DP0!``"#P/^#TO^)1"08B=>)
M5"0<P?\?B?XQ\"GP,=(E__\``#'Z,?`I\(MT)!@9^HM\)!PIQAG7@\00C6PD
M%(7_#XB@````C70F`&H`5U;_="00_Y,$`0``@\0,:`@``0!5_W0D$/^35```
M`(/$$(/X!W97C40%^#GH<D^-%2`!``#K#HVT)@````"#Z`$YZ'(YBPP:.0AU
M\HN+)`$``#E(!'7G*>B9`?`1^HN,)!P``0!E*PT4````=3B!Q"P``0!;7E]=
MPXUT)@"0@<8``/__@]?_B?")^C4``/__]]()T`^%9/___[C_____NO_____K
MN.BS*```C78`5>A'&```@<7RE@``5XG'5E.)TX/L.&6A%````(E$)"@QP#'`
M@#H]#Y3``<-3_Y68````@\00B40D!(GXC50D&.B+^___A<`/A!,!``"#[`R)
MQE#_E9@```"+3"04@\00.<@/@]@```"+1"08P>`"B40D"(N%K````(D$)`^V
M!X3`#X2I`0``/#T/A*$!``")^(VT)@`````/ME`!@\`!A-)T!8#Z/77P*?B+
M#"2+="0(@^P,BU0D$`,QC400`E#_E;P```")!H/$$(7`=%&+#"2+="0(BP&-
M3P&+%#`/M@>(`CP]=!V$P'4*ZQ>-="8`/#UT#P^V`8/"`8/!`8@"A,!U[<8"
M/3'`C;0F`````)`/M@P#B$P"`8/``83)=?&+1"0<92L%%`````^%$P$``(/$
M+%M>7UW#C;0F`````)`QP(VV``````^V%`.(%`:#P`&$TG7RZ\>-M"8`````
MD(N%K````(L0B00DBS*%]@^$P@```#'VC;0F`````&:0B?"#Q@&+#+*%R77T
MC02%#````(N--`$``(7)=6.)5"0,@^P,4,>%-`$```$```#_E;P```")P8/$
M$(7`#X1=____C02U`````(/L!(E$)`Q0BU0D%%)1B4PD'/^5W````(M$)!"+
M3"0<@\00B0C'1+$$`````(ET)!CI??[__Y"#[`A04O^5.````(G!BT0D$(/$
M$(D(A<D/A`'___^-!+4`````B40D".O#C70F`)`QP.ES_O__N`@````Q]NE0
M____Z&@F``"-M"8`````D%575E.![``0``"##"0`@^PPZ.,5``"!QY*4``")
M5"00B<9EH10```")A"0@$```,<!H_P\``(V')J'__XUL)"154/^7V````(/$
M$(7`?A")PXU`_X!\'!L`=46%P'4YBX=X````@^P$_W0D$%9E_S#_ETP```"#
MQ!"+A"0<$```92L%%````'5"@<0L$```6UY?7<.-="8`B<.-M@````"#[`13
M:B]5_Y?L````@\00A<!TJXN'>````%-55F7_,/^7I````(/$$.NNZ)`E``!6
M4^BI]___@</1DP``@^P$C8-8X?__B[-X````4(V#-:'___^S?````%!E_S;_
MD_@```!8C8.\HO__6FH`4%"-@UA^__]0C8-1H?__4&7_-O^3A````(/$)%M>
MPXUT)@#HO!0```5SDP``@^P,C9!8X?__4HV0-:'___^P?````%*+D'@```!E
M_S+_D/@```"#Q!S#C;0F`````(UT)@"055=64X'L`!```(,,)`"![``0``"#
M#"0`@^P<,>WH[O;__X'#%I,``&6A%````(F$)`P@```QP/^3%````(/L"(V3
M,:'__U)0C8-FH?__4&@!$```:@&-="0F5O^3Z````(/$'&@`$```C;PD$Q``
M`%=6_Y/8````@\00A<!X+(/L#(G&C4`!4/^3O````(G%@\00A<!T%(/L!%97
M4/^3E````,9$-0``@\00BX0D#"```&4K!10```!U#8'$'"```(GH6UY?7</H
M(R0``(UV`.DK____C;0F`````(UT)@!55U93@>P`$```@PPD`('LG````.@7
M]O__@<,_D@``B[PDL!```(NL)+00``!EH10```")A"2,$```,<"-1"0LB40D
M%(G"C8-TH?__Z-_V__^#[`AJ+XG&5_^3/````(/$$(7`=#*-@WVA__^)^NCM
M^O__B?B+E"2,$```92L5%`````^%F0$``('$G!```%M>7UW#C70F`(/L#%7_
MDP`!``!:68V+BJ'__XE,)!114/^3T````(V+C*'__XG%C8-\HO__@\00B40D
M&(7M=)>`?0``B4PD'`^$Z@```(UV`(7V=!:#[`A55O^3"`$``(/$$(7`#X2G
M````@^P,5?^3F````(G"C40%_X/$$#G%<A'K(XUT)@"0Q@``@^@!.<5T!8`X
M+W3Q@^P,5?^3F````(G"@\00B50D$(/L#%?_DY@```"+5"0@C40"`8/$$#W_
M#P``#X<,____@^P$5_]T)"15_W0D*&@`$```:@&-K"2H````5?^3Z````(/$
M&/]T)!Q5_Y-L````@\00A<!U$(M$)#PE`/```#T`@```=$^#[`C_="04:@#_
MD]````")Q8/$$(7`#X2I_O__@'T```^%&?___X7V=`6`/BYT$+H!````C:MR
MH?__Z5;___^`?@$`=+OKZ(VT)@````"0@^P(:@%5_Y-D````@\00A<!UGHGJ
MC8-]H?__Z%#Y__^#[`Q5_Y,``0``@\00Z5/^___HZ2$``(VT)@````!FD%;H
M;Q$``('&(I```%.#[`R+7"08:B]3_Y90````@\00A<!T`XU8`8E<)!"#Q`2)
M\%M>_Z```0``C;0F`````)!55U93@>P`$```@PPD`(/L'.@G$0``@<72CP``
MB[0D,!```&6A%````(F$)`P0```QP(7V#X2F````@#X`#X2=````@^P,5O^5
MF````(U(`8/$$('Y`!````^'X0```(U<)`R#^00/@Z0```"%R0^%W````(U$
M`_\YPW(.ZQ%FD,8``(/H`3G8=`6`."]T\8/L"&HO4_^54````(/$$(7`=#XY
MPP^"A@```(/L#%/_E0`!``"#Q!"+E"0,$```92L5%`````^%I````('$'!``
M`%M>7UW#C;0F`````(UV`(N$)`P0``!E*P44````=7^-A7*A__^)A"0P$```
M@<0<$```B>A;7E]=_Z```0``D(M4#OR)WXE4#`B)P<'I`O.EZ4[___^-M"8`
M````C78`Q@``Z7+___^-M"8`````D#'`Z7#___^-M"8`````9I`/MA:(5"0,
M]L$"#X04____#[=4#OYFB50,"ND%____Z"P@``"-M"8`````C70F`)!55U;H
MK0\``('&8(X``%.#["QEH10```")1"0<,<"-7"08BZZL````C;Z.H?__B=J)
M^.@)\___A<!T+HM4)!B+10"-!)"+4`2)$(72=.!FD(M0"(/`!(D0A=)U](G:
MB?CHV_+__X7`==*+KJP```"-OI>A__^)VHGXZ,+R__^%P'0OBU0D&(M%`(T$
MD(M0!(D0A=)TX(UV`(M0"(/`!(D0A=)U](G:B?CHD_+__X7`==&+KJP```"-
MOI^A__^)VHGXZ'KR__^%P'0OBU0D&(M%`(T$D(M0!(D0A=)TX(UV`(M0"(/`
M!(D0A=)U](G:B?CH2_+__X7`==&+KJP```"-OJBA__^)VHGXZ#+R__^%P'0O
MBU0D&(M%`(T$D(M0!(D0A=)TX(UV`(M0"(/`!(D0A=)U](G:B?CH`_+__X7`
M==&-AJ^A__^+OJP```")!"2+!"2)VNCF\?__A<!T+(M4)!B+!XT$D(M0!(D0
MA=)TX(M0"(/`!(D0A=)U](L$)(G:Z+KQ__^%P'74BZZL````C;Z_H?__B=J)
M^.BA\?__A<!T-HM4)!B+10"-!)"+4`2)$(72=."-M"8`````C78`BU`(@\`$
MB1"%TG7TB=J)^.AK\?__A<!URHV&=*'__XN^K````(E$)`2+1"0$B=KH3/'_
M_X7`=#.+5"08BP>-!)"+4`2)$(72=-^-M@````"+4`B#P`2)$(72=?2+1"0$
MB=KH&?'__X7`=<V-ALNA__^+OJP```")1"0,BT0D#(G:Z/KP__^%P'0QBU0D
M&(L'C020BU`$B1"%TG3?C70F`(M0"(/`!(D0A=)U](M$)`R)VNC)\/__A<!U
MSXV&U:'__XN^K````(E$)`B+1"0(B=KHJO#__X7`=#&+5"08BP>-!)"+4`2)
M$(72=-^-="8`BU`(@\`$B1"%TG7TBT0D"(G:Z'GP__^%P'7/BZZL````C;[?
MH?__B=J)^.A@\/__A<!T-8M4)!B+10"-!)"+4`2)$(72=."-M"8`````9I"+
M4`B#P`2)$(72=?2)VHGXZ"OP__^%P'7+BZZL````C;Y]H?__B=J)^.@2\/__
MA<!T+XM4)!B+10"-!)"+4`2)$(72=."-=@"+4`B#P`2)$(72=?2)VHGXZ./O
M__^%P'71B=J-ANFA___HTN___X7`=`N)PHM$)`CH\_/__XG:C8;ZH?__Z+;O
M__^%P'0-B<*-A@RB___HU?/__XG:C887HO__Z)CO__^)PH7`="N+1"0$Z+GS
M__^+1"0<92L%%````'4SBP0D@\0LC98XHO__6UY?7>F7\___B=J-AB>B___H
M6N___X7`=,V)PHM$)`SH>_/__^O`Z"0<``"-="8`Z*P+```%8XH``(/L'&6+
M%10```")5"0,,=*-5"0(C8#+H?__Z!?O__^%P'0K#[80@/HP#Y3`A-(/E,()
MT(/P`0^VP(M4)`QE*Q44````=0R#Q!S#C70F`#'`Z^?HOQL``(VT)@````"-
MM"8`````D%/HRNW__X'#\HD``(/L"/^3J````(/L#%#_DZ````"#Q!"%P'0"
MBP"#Q`A;PXUV`%575N@-"P``@<;`B0``4X/L+&6A%````(E$)!PQP(U4)!B+
M;"1`C;XZHO__B?CH;>[__X7`=`>`.`")PW4BBT0D'&4K!10````/A:4```")
MZH/$+(GX6UY?7>EQ\O__D(/L"%50_Y:X````@\00A<!T'HM$)!QE*P44````
M=76#Q"Q;7E]=PXVT)@````!FD(/L#%7_EI@```")1"0<B1PD_Y:8````BU0D
M'(U$`@*)!"3_EKP```"#Q`R)PHV&BJ'__U-0C89\HO__55!J_VH!4HE4)"S_
MEN@```"#Q""+5"0,BT0D'&4K!10````/A%W____HAQH``(VT)@````!55U93
MZ)?L__^!P[^(``"![/P```"+A"00`0``C7PD+(GZB40D#&6A%````(F$).P`
M```QP(V#4:+__\>$))0`````````B80DC````(V#<J'__XF$))````"-@P6B
M__^)A"2H````C8-6HO__B80DK````(V#(J+__XF$)+````"-@UZB__^)A"2T
M````C8-BHO__B80DF````(V#9Z+__XF$))P```"-@W2A___'A"2X````````
M`,>$)*``````````B40D&.C3[/__A<!T"X`X`(G&#X6,!```_Y.H````@^P,
M4/^3H````(/$$(7`#X39`P``BRB%[0^$SP,``(/L#%7_DY@```"-1``!@\00
M@^P,4/^3O````(G&#[9%`(/$$(ET)`B$P'0[C8MPHO__B7PD!(GWB<Z-="8`
MD(/L#`^VP(/%`5!6:O]J`5>#QP+_D^@````/MD4`@\0@A,!UW(M\)`2-M"2D
M````C8,,HO__ZQ.-M"8`````9I"+1@2#Q@2%P'0VB?KH#^S__XG%A<!TZ8`X
M`'3DZ-_L__^%P'3;@^P,5?^3``$``(G%@\00A<!U.(VT)@````"0C;0DC```
M`(LNA>UT(X!]```/A/$"``")Z.BB[/__A<`/A?(```"+;@2#Q@2%[77=@^P,
M5?^3F````%K_="04B<;_DY@```"-M`8$!```B30D_Y.\````B40D%(G!C8-U
MHO___W0D&%"-@XRA__^)1"0@4(V#>J+__U6)S5!J_VH!4?^3Z````(/$*&C`
M`0``5?^3&````(/$$(/X_W41_Y,0````BP"#^!$/A=@"``"#[`A7_W0D$/^3
MU````(G%@\00A<!T>8/L#/]T)!"+1"0<_S"-@R2C__]0,?:+@Y````!J`?\P
M_Y,L````@\0@BX0D[````&4K!10````/A58$``"!Q/P```")\%M>7UW#C;0F
M`````(/L#(/&!%7_DP`!``")Q8/$$(7`#X35_O__Z?G^__^-M"8`````9I"+
M1"0\)0#P```]`$````^%<____XM$)$2)1"00_Y.H````.40D$`^%6____XM$
M)#PE_P$``#W``0``#X5'____@^P,5O^3O````(GZB<:-@T6B___H1^K__X/$
M$(7`#X1$`@``@^P(4(M$)!C_,.C]\O__B40D((/$$(7`#X0F`@``@^P,_W0D
M'/^3F````(G"@\00@_@#=D>#[`B-@X.B__]0BT0D'(U$$/R)5"0H4/^3"`$`
M`(/$$(7`=2.+5"0<@_H$#X3V`@``BT0D$(!\$/LO#X3G`@``C;0F`````(GZ
MC;O+H?__B?CHL>G__X7`#X3)`0``#[8`A,`/A+X!```\,`^$M@$``(V3.*+_
M_XGXC;N\HO__Z+/M____DQ0```!74(V#G*+___]T)!#_="004&K_:@%6_Y/H
M````C8.JHO__@\0@B40D#.LV9I#_DQ````"#.!%U0/^3%````(/%`8/L#%=5
M4/]T)"#_="0@_W0D+&K_:@%6_Y/H````@\0P@^P(:,`!``!6_Y,8````@\00
M@_C_=+6#[`S_="00_Y-@````BT0D*(GRZ!WM__^)-"3H1?K__X/$$.GM_?__
MC70F`)`Q[>DA_?__D(N$))@```"-M"28````A<!T((VV`````(GZZ+'H__^%
MP'0%@#@`=3B+1@2#Q@2%P'7F@^P,C:M*HO__:@W_D[P```")QH/$$(E$)`BX
M4P```.D'_/__C;0F`````(UV`(/L#%#_DP`!``")Q8/$$(7`=+7IN?O__X/L
M"%#_="00BT0D'/\PC8/HHO__Z3G]__^-M"8`````@^P,4.B/^?__@\00BX0D
M[````&4K!10````/A9(!``")M"00`0``@<3\````B=A;7E]=_Z```0``C;0F
M`````(M$)`R+`(E$)!#IR_W__XVT)@````!FD(/L"&H`_W0D'/^3*````(/$
M$(7`#X0P_O__B40D#.BMZO__B40D$(E4)!2%T@^(%_[__X/`]FH`@]+_4E"+
M3"0848E,)!S_DP0!``"#Q`QJ!HV$),4```!0BTPD&%&)3"0<_Y-4````@\00
MBTPD#(&\)+T`````0T%##X7*_?__9H&\),$```!(10^%NOW__VH`BT0D%(M4
M)!B#P,Z#TO]24%&)3"0<_Y,$`0``@\0,:BB-O"3+````5XM,)!A1_Y-4````
MC8.\HO__QH0D^P````!0C8.-HO__5_]T)"#_="0@4&K_:@%6_Y/H````@\0P
MZ>3]__^-M"8`````9I"+1"0,BU`$A=(/A!']__^#[`Q2B50D'/^3F````(/$
M$(/X`P^&]_S__X/L"(V+B*+__U&+5"08C40"_%#_DP@!``"#Q!"%P`^%T_S_
M_XM4)`R)5"00Z<;\___H81,``)!55U93Z'?E__^!PY^!``"#[!QEH10```")
M1"0,,<"-?"0(B?J+LW@```!EBRX/MD5DB$5EC8.OH?__Z$'F__^%P'0)@#@Q
M#X1D`0``Z._R__]EBRZ-@[NB__]J`VH!4%7_DT@```")Q8/$$(7`="J#[`2-
M@[VB__]0BT4,_S!E_S;_DTP```"+10R+`(/$$/9`"D`/A4<!``"-@\*B__]J
M`VH!4&7_-O^32````(G%@\00A<!T*HGZC8-]H?__Z+WE__^%P`^$]0```(/L
M!%"+10S_,&7_-O^33````(/$$(/L!(V#Q*+__VH!4&7_-O^3(````(V3V:+_
M_X/$#%)09?\V_Y-,````98L&B?K&0&4`C8-TH?__Z&/E__^#Q!")@S@!``")
MQH7`=$2#[`AHP`$``%;_DQ@```"-4`&#Q!"#^@%V"8/X$0^%I@```(M$)`QE
M*P44````#X6Y````@\0<6UY?7<.-M"8`````D(/L#/^S/`$``.AB]___@\00
MB8,X`0``B<:%P'6?BT0D#&4K!10```!U?X/L#(V#>*/__U#_D^````"-M@``
M``"`>`$`#X2:_O__Z8W^__^0BX,\`0``BQ"+10R+`.@NZ___Z0G___^-M"8`
M````9I"#[`A09?\V_Y/$````@\00Z:3^__^+5"0,92L5%````'474(N#/`$`
M`%;_,(V#G*/__U#_D^````#H0A$``&:05U;HS@```('&@7\``%.#[!QEH10`
M``")1"08,<"+?"0L5^AY[___6EEJ+U")P_^64````(/$$(7`=`.-6`&#[`Q3
M_Y8``0``B<.-ALNA__^-5"08Z`?D__^#Q!"%P'0@#[80A-(/E,"`^C`/E,((
MT'4.A?]T"H`_`'4=C70F`)"+1"0,92L%%````'4_@\006UY?PXUT)@"#[`2-
MAG6B__]J!%!3_Y;P````@\00A<!USHM$)`QE*P44````=0V#Q!")^%M>7^D$
MY?__Z&\0``"+!"3#BS0DPXL\),.++"3#9I!FD&:09I!FD&:09I"055=64XG#
M@>Q\`0``B40D$(U,)"QEH10```")A"1L`0``,<"-="8`D(M4@QP/RHD4@8/`
M`8/X$'7OBTPD,(MT)&"-5"0TBVPD9(M$)&B)3"0(C8PD-`$``(M<)"R)3"0,
MZPJ-M@````")3"0(BPJ)QXM"&(/"!#'(,?")[HG],=B+7"0(T<")0C0Y5"0,
M==F+?"00BT0D+(LWBU<0BV\(BU\,B50D'(V4`IEY@EJ)\(M/!,'`!8GWB5PD
M"`'"B>B)3"04,=B)?"0,(<C!R0*);"08,=B+7"0P`<*)Z#'((?"+="0(,>B-
MM!Z9>8):BUPD-`'&B=#!P`6-G!V9>8):BVPD.`'&B?C!R`*)QXG(,?@AT,'*
M`C'(C8PIF7F"6HML)#P!PXGPP<`%`<.)^#'0(?#!S@(Q^(V\+YEY@EJ+;"1`
M`<B)V<'!!0'(B=$Q\2'9,=&-E"J9>8):BVPD1`'YB<?!QP7!RP(!^8GW,=\A
MQ\'(`C'WC;0NF7F"6HML)$@!^HG/P<<%`?J)QXG8,?@AR#'8C9PKF7F"6HML
M)$P!\(G6P<8%`?")SHGYP<X",?$AT3'YC;POF7F"6HML)%`!V8G#P<,%`=F)
MTXGRP<L",=HAPL'(`C'RC;0NF7F"6HML)%0!^HG/P<<%`?J)QXG8,?@AR#'8
MC9PKF7F"6HML)%@!\(G6P<8%`?")SHGYP<X",?$AT3'YC;POF7F"6HML)%P!
MV8G#P<,%`=F)TXGRP<L",=HAPL'(`C'RC;0NF7F"6HML)&`!^HG/P<<%`?J)
MQXG8,?@AR#'8C9PKF7F"6HML)&0!\(G6P<8%`?")SHGYP<X",?$AT3'YC;PO
MF7F"6@'9B</!PP4!V8G3B?+!RP(QVB'"P<@",?*)Q8G8`?J)SS'HP<<%(<C!
MR0(!^HM\)&@QV(VT/IEY@EJ+?"1L`?")UL'&!8V\.YEY@EH!\(GN,<Z)PR'6
MP<,%,>[!R@(!]XMT)'`!WXG+,=.-M#69>8):BVPD="'#P<@",<N-C"F9>8):
MBVPD>`'>B?O!PP4!WHG3,<,A^S'3P<\"C90JF7F"6@'+B?'!P04!RXG!,?DA
M\<'.`C'!`=&)VL'"!0'1BU0D?(V$$*'KV6Z)^C'R,=K!RP(!PHG(P<`%`<*+
MA"2`````C;P'H>O9;HGP,=@QR,')`@'XB=?!QP4!^(G/BXPDA````(VT#J'K
MV6Z)V3'Y,=$!\8G&P<8%`?&)UHN4)(@```#!S@*-G!.AZ]ENB?HQ\C'"`=J)
MR\'(`L'#!0':B<.+A"2,````C;P'H>O9;HGP,=@QR,')`@'XB=?!QP4!^(G/
MBXPDD````(VT#J'KV6Z)V3'Y,=$!\8G&P<8%`?&)UHN4))0```#!S@*-G!.A
MZ]ENB?HQ\C'"P<@"`=J)R\'#!0':B<.+A"28````C;P'H>O9;HGP,=@QR,')
M`@'XB=?!QP4!^(G/BXPDG````(VT#J'KV6Z)V3'Y,=$!\8G&P<8%`?&)UHN4
M)*````#!S@*-G!.AZ]ENB?HQ\C'"P<@"`=J)R\'#!0':B<.+A"2D````C;P'
MH>O9;HGP,=@QR,')`@'XB=?!QP4!^(G/BXPDJ````(VT#J'KV6Z)V3'Y,=$!
M\8G&P<8%`?&)UHN4)*P```#!S@*-G!.AZ]ENB?HQ\C'"P<@"`=J)R\'#!0':
MB<.+A"2P````C;P'H>O9;HGP,=@QR,')`@'XB=?!QP4!^(G/BXPDM````(VT
M#J'KV6Z)V3'Y,=$!\8G&P<8%`?&)UHN4)+@```#!S@*-G!.AZ]ENB?HQ\C'"
MP<@"`=J)R\'#!0':B<.+A"2\````C;P'H>O9;HGP,=@QR,')`@'XB=?!QP4!
M^(G/BXPDP````(VT#J'KV6Z)V3'Y,=$!\8G&P<8%`?&)UHN4),0```#!S@*-
MG!.AZ]ENB?HQ\C'"P<@"B<4!VHN$),@```")R\'#!0':C9P'H>O9;HGP,>@Q
MR`'8B=/!R0+!PP4!V(GK"<N)WXGK(=<AR\'*`@G[B[PDS````(VT/MR\&X\!
M\XG&P<8%`?.)S@G6B?>)SB''(=;!R`()_HN\)-````"-O#W<O!N/`?>)WL'&
M!0'WB=8)QHGUB=8AW2'&P<L"">Z+K"34````C8PIW+P;CXG=B<,!SHGY">O!
MP04A^P'.B<$AZ0G9BYPDV````(V<&MR\&X^)\@'+P<\"B>G!P@4)^0'3B>HA
M\<'.`B'Z"<J+C"3<````C8P(W+P;CXG8`='!P`4!P8GX"?")PHGX(=HA\,'+
M`@G0BY0DX````(V4%=R\&X\!PHG(P<`%`<*)\`G8B<6)\"'-(=C!R0()Z(NL
M).0```"-O"_<O!N/B=T!^(G7"<W!QP4AU0'XB<^)V2'Y">F+K"3H````C;0N
MW+P;CXG]`?&)QL'&!0'QB=:)^L'.`@GU(?(AQ<'(`@GJBZPD[````(V<*]R\
M&X\!VHG+P<,%`=J)PXGP"=B)Q8GP(<TAV,')`@GHBZPD\````(V\+]R\&X^)
MW0'XB=<)S<''!2'5`?B)SXG9(?D)Z8NL)/0```"-M"[<O!N/B?T!\8G&P<8%
M`?&)UHGZP<X""?4A\B'%">J+K"3X````C9PKW+P;CP':B<O!R`+!PP4!VHG#
MB?`)V(G%B?`AS2'8P<D"">B+K"3\````C;POW+P;CXG=`?B)UPG-P<<%(=4!
M^(G/B=DA^0GIBZPD``$``(VT+MR\&X^)_0'QB<;!Q@4!\8G6B?K!S@()]2'R
M(<7!R`()ZHNL)`0!``"-G"O<O!N/B<4!VHG+P<,%`=J)\PG#B?`ARR'H"=B+
MG"0(`0``C9P?W+P;CP'8B=/!R0+!PP4!V(GK"<N)WXGK(=<AR\'*`@G[B[PD
M#`$``(VT/MR\&X\!\XG&P<8%`?.)S@G6B?>)SB''(=;!R`()_HN\)!`!``"-
MO#W<O!N/B=4!_HG?"<7!QP4AW<'+`@'^B=<AQPGOBZPD%`$``(V,*=R\&X^)
MQ0'YB?<)W<''!2'U`?F)QR'?">^+K"08`0``C90JW+P;CXML)`P!UXG*P<X"
MP<(%`=>+E"0<`0``C900UL%BRHG8,?`QR,')`@'0B?K!P@4!T(N4)"`!``"-
MG!/6P6+*B?(QRC'ZP<\"`=J)P\'#!0':BYPD)`$``(VT'M;!8LJ)RS'[,<,!
M\XG6P<8%`?.)QHN$)"@!``#!S@*-C`'6P6+*B?@Q\#'0P<H"`<B)V<'!!0'(
MB=&+E"0L`0``C907UL%BRHGW,<\QWP'7B<+!P@4!UXN4)#`!``#!RP*-M!;6
MP6+*B<HQVC'"`?*)_L'&!0'RB<:+A"0T`0``P<X"C80!UL%BRHG9,?$Q^<'/
M`@'!B=#!P`4!P8N$)#@!``"-G`/6P6+*B?`Q^#'0`=B)R\'#!0'8B=.+E"0\
M`0``P<L"C906UL%BRHG^,=XQSL')`@'6B<+!P@4!UHN4)$`!``"-O!?6P6+*
MB=HQRC'"P<@"`?J)]\''!0'ZB<>+A"1$`0``C80#UL%BRHG+,?LQ\\'.`@'#
MB=#!P`4!PXN$)$@!``"-C`'6P6+*B?@Q\#'0P<H"`<B)V<'!!0'(B=&+E"1,
M`0``C907UL%BRHGW,<\QW\'+`@'7B<+!P@4!UXN4)%`!``"-M!;6P6+*B<HQ
MVC'"`?*)_L'&!0'RB<:+A"14`0``P<X"C80!UL%BRHG9,?$Q^<'/`@'!B=#!
MP`4!P8N$)%@!``"-G`/6P6+*B?`Q^#'0`=B)R\'#!0'8B=.+E"1<`0``P<L"
MC906UL%BRHG^,=XQSL')`@'6B<+!P@4!UHN4)&`!``"-O!?6P6+*B=HQRC'"
MP<@"`?J)]\''!0'ZB[PD9`$``(V\.];!8LJ)RS'#,?/!S@(!^XG7P<<%`?N+
MO"1H`0``C;P]UL%BR@'/B<$Q\3'1P<H"`?F)W\''!0'YBWPD$(D/BTPD%`'9
MB4\$BVPD&(M,)`@!ZHE7"(T4,8E7#(M4)!P!T(E'$(N$)&P!``!E*P44````
M=0N!Q'P!``!;7E]=P^AQ!```D.C\\___!;-R``"#[!AJ8/^0O````,<``2-%
M9\=`!(FKS>_'0`C^W+J8QT`,=E0R$,=`$/#ATL/'0!0`````QT`8`````,=`
M7`````"#Q!S#55=6Z*WS__^!QF!R``!3@^P<BUPD,(M$)#B+?"0TP>`#`T,4
MBTL8C6L<B4,4BT0D.(/1`,'H'0'(B4,8BT-<A<`/A3$!``"#?"0X/P^.?@$`
M`(M$)#B#Z$")1"0,P>@&C7`!B40D",'F!@'^C70F`(L'@\=`B44`BT?$B44$
MBT?(B44(BT?,B44,BT?0B440BT?4B444BT?8B448BT?<B44<BT?@B44@BT?D
MB44DBT?HB44HBT?LB44LBT?PB44PBT?TB44TBT?XB44XBT?\B44\B=CH]_+_
M_SGW=9.+1"0(BU0D#,'@!BG"B50D.(-\)#@$<E.+!HGIB4,<BT0D.(M4)#B+
M1`;\B405_(U#((/@_"G!*<X#3"0X@^'\@_D$<A*#X?PQTHLL%HDL$(/"!#G*
M<O.+1"0XB4-<@\0<6UY?7<.-="8`D(M$)#B%P'3D#[8&B$,<]D0D.`)TUXM$
M)#B+3"0X#[=$!OYFB40-_NO#C;0F`````+I`````*<([5"0X?SN#[`2-:QQ2
M`>B)5"005U#_EI0```"+5"08BT-<`="#Q!")0UR#^$!UC8G8*50D.`'7Z!7R
M___IA_[__XM4)#CKOXVT)@````"-=@")_ND7____C;0F`````&:0Z,SQ__\%
M@W```%575E.#[!R+7"0TBW0D,(E$)`2+4Q2+:QB->QR)T,'J`P_-@^(_#\B)
M1"0(C4(!QD03'("#^#@/C@D!``"Z0````(T,!RG"=",QP/;"`70,N`$```#&
M`0`YT',0Q@0!`,9$`0$`@\`".=!R\(G8Z'/Q__^-5P3'0QP`````,<"#XOS'
M1S0`````*=>-3SB)U\'I`O.KBT0D"(EK5(E#6(G8Z$#Q__^+`\'H&(@&BP/!
MZ!"(1@&+`XAF`HL#B$8##[9#!XA&!`^W0P:(1@6+0P2(9@:+0P2(1@</MD,+
MB$8(#[=#"HA&"8M#"(AF"HM#"(A&"P^V0P^(1@P/MT,.B$8-BT,,B&8.BT,,
MB$8/#[9#$XA&$`^W0Q*(1A&+0Q"(9A*+0Q"(1A.+1"0$B5PD,(/$'%M>7UW_
MH&````"-M"8`````C78`NC@````IP@'X@_H$#X*.````C4@$QP``````@^'\
MQT00_``````IR`'0@^#\@_@$#X(9____B<>Z!````(/G_(E\)`R->/_![P+'
M`0````"#YP$YP@^#]/[__X7_=!C'000`````BT0D#+H(````.<(/@]C^__^+
M1"0,QP01`````,=$$00`````@\((.<)RZNFY_O__C;0F`````(UV`(72#X2G
M_O__Q@``]L("#X2;_O__,<EFB4P0_NF/_O__Z+SO__\%<VX``(/L#/^P'`$`
M`/]T)!S_="0<_W0D'/^00````(/$',-FD&:09I"05E[HBN___P5!;@``@^P,
M_Y#(````````4X/L".C_T?__@<,G;@``@\0(6\,`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````P````$``@`E<R\E<P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R
M.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O
M)6DO)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%
M4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,
M7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!
M3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`,0!,1%],24)205)97U!!5$@`4UE3
M5$5-`"]T;7``5$5-4$1)4@!435``55-%4@!54T523D%-10`E,#)X`'!A<BT`
M)7,E<R5S)7,`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U
M)7,`)7,E<W1E;7`M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D52
M4TE/3@`Q+C`U.``M90`M+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T
M92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET
M(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!5;F%B;&4@=&\@8W)E871E
M(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C
M86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````&5V
M86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P
M.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A
M<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C
M:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M
M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A
M8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P
M-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@
M)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@
M+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H
M=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@
M)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O
M<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"10
M05)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'
M24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU
M;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N
M86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[
M4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;
M4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ
M9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P
M87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F
M)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M
M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)
M3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R
M:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N
M90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@
M)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^
M)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]
M"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE
M9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV
M*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H
M"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I
M+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I
M;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>
M35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D[
M"F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R
M7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?
M5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T
M:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT[
M"G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S
M*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O
M;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@
M34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I
M.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA
M9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI
M.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I
M=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)
M3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?
M1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#
M04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@
M;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M
M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O
M9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO
M=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D
M;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@[
M"FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@
M("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H
M:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@
M/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN
M72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO
M?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B
M=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E
M9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I
M*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@
M/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA
M;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(
M+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D
M;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U
M;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@
M=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*
M)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H
M)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@
M>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG
M="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M
M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N
M("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O
M+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D
M9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F
M:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO
M9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@
M/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.
M0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H
M)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64[
M"GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S
M:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T
M<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@
M(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT
M96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]
M"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A
M8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI
M=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D
M<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@
M<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*
M:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A
M<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q
M("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%
M?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V
M:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=
M(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D
M,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q
M(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I
M('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I
M('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]
M("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL
M)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@
M*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q
M6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E
M<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF
M("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%2
M7U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z
M.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#
M+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ
M1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI3
M2$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E
M9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D
M:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H
M)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH
M("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II
M<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H
M)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG
M*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N
M*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII
M9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R
M(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM
M>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N
M;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC
M;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&
M:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL
M93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R
M(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB
M:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F
M:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A
M9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D
M+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]6
M15)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A
M9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B
M.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U
M:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG
M<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[
M<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C
M:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D
M97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E
M>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@
M;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K
M97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF
M("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME
M>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92![
M"F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D
M:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*
M;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@
M>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D
M;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I
M('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*
M?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I
M='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@
M/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN
M9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT
M96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D
M=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B
M/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD
M("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M
M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA
M;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T
M:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET
M=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E
M5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF
M("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*
M?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@
M/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^
M861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D
M8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE
M7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<
M,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D[
M"B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F
M9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN
M="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E
M(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D
M(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D
M969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!0
M05(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E
M($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]
M($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C
M($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^
M9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F
M86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(
M*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E
M("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@
M*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP
M+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD
M(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D
M>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y
M.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U
M;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R
M86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A
M=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@
M)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I
M>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E
M(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@
M>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T
M7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;
M17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET[
M"F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*
M?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I
M92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@
M72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A
M;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'
M5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A
M=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O
M<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER
M92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T
M.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R
M<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@
M1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)
M3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S
M.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z
M.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T
M<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E
M(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L
M('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E
M<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I
M<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R
M97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P
M871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%
M35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW
M("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I
M9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN
M960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z
M.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N
M86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).
M04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER
M(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R
M;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII
M9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"([
M"GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D
M;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K
M("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H
M*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG
M=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@
M)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H
M(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D
M8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H
M95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D
M8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%2
M7T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H
M95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@
M/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?
M<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*
M;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@
M)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM
M>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I
M;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T
M96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D
M9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L
M;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK
M*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@
M*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%2
M7U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L
M(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H
M(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N
M86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D
M<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N
M.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P
M?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]4
M14U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1
M)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER
M)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE
M(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@
M(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O
M9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345]
M.PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD
M<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W
M9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@
M*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z
M(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN
M/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@
M>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R
M;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@
M*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@
M*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6
M>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?
M)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%2
M7T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@
M*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN
M="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*
M<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[
M)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I
M=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K
M86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF
M:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP
M;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C
M:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID
M;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]
M("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ
M7U]%4E)/4CL*,3L*7U]%3D1?7PH``$-!0TA%``!P97)L>'-I+F,````!&P,[
M$`$``"$```#4?___6`$``/1___],#```1(+__RP!``!T@___?`$``%2$___T
M`0``Y(3__T`"``!DAO__]`(``*2'__^$`P``](G__P0$``#$BO__E`0``"2+
M___D!```9(O__P@%```TC/__H`4``$2,__^T!0``=([__[0&``"TCO__Z`8`
M`#20__]L!P``-)3__ZP'``"DE/__R`<``-24___T!P``U)7__W@(``#TG/__
M"`L``!2?___8"P``Y9___Y0,``#IG___J`P``.V?__^\#```\9___]`,```$
MH/__Y`P``.2K__\H#0``-*S__T0-```4KO__E`T``"2P___4#0``5+#___@-
M```4``````````%Z4@`!?`@!&PP$!(@!!P@0````'````!"!__\L````````
M`!0``````````7I2``%\"`$;#`0$B`$``"`````<````='[__R``````#@A&
M#@Q*#PMT!'@`/QH[*C(D(G0```!`````\('__]P`````00X(A0),#@R'`T$.
M$(8$00X4@P5##C`"20XT00XX1`X\00Y`20XP60H.%$/##A!!Q@X,0<<."$'%
M#@1'"W0*#A1#PPX00<8.#$''#@A!Q0X$1@M##A1%PPX00<8.#$''#@A!Q0X$
M`$@```"X````6(+__X(`````00X(A@),#@R#`T4.B`%1#HP!00Z0`4D.@`%A
M#H@!0@Z,`4$.D`%)#H`!8`H.#$'##@A!Q@X$00L```"P````!`$``)R"__]^
M`0```$$."(4"00X,AP-!#A"&!$P.%(,%2`Z@`6P*#A1!PPX00<8.#$''#@A!
MQ0X$20M##JP!00ZP`4L.H`%'#JP!00ZP`4D.H`%Q#JP!00ZP`6D.K`%'#J@!
M10ZL`4$.L`%!#K0!0@ZX`4(.O`%!#L`!20ZH`44.K`%!#K`!20Z@`5@.K`%!
M#K`!20Z@`4,.K`%!#K`!20Z@`4X.K`%!#K`!4@Z@`0",````N`$``&B#__\]
M`0```$$."(4"00X,AP-!#A"&!$$.%(,%1PP#E(`$3@T$0P[`@`1B#L2`!$(.
MR(`$0@[,@`1!#M"`!'T.P(`$4@[$@`1!#LB`!$$.S(`$1`[0@`1)#L2`!$4.
MR(`$00[,@`1$#M"`!$D.P(`$`E(*#A1!PPX00<8.#$''#@A!Q0X$1@M\````
M2`(``!B$__](`@```$$."(4"3`X,AP-##A"&!$$.%(,%10Y,5PY020Y`6@Y,
M0PY030Y``E0.3$L.4$L.0`)I"@X40<,.$$'&#@Q!QPX(0<4.!$D+`F0.3$$.
M4%4.0%(.1$4.2$4.3$$.4%4.0%<.2$$.3$$.4$\.0````(P```#(`@``Z(7_
M_]``````00X(A0)!#@R'`T$.$(8$00X4@P5&#I0@1P[$(&4.R"!+#LP@00[0
M($D.P"!=#L0@1`[(($$.S"!##M`@20[`(%8*#A1!PPX00<8.#$''#@A!Q0X$
M10M+#L0@00[(($(.S"!!#M`@20[`($L.Q"!!#L@@00[,($,.T"!)#L`@`$P`
M``!8`P``*(;__UP`````00X(A@)!#@R#`TX.$$T.%$P.&$$.'$,.($<.'$<.
M&$(.'$$.($$.)$<.*$<.+$,.,$D.#$'##@A!Q@X$````(````*@#```XAO__
M-`````!-#A!'#A1,#AA!#AQ)#B!)#@0`E````,P#``!4AO__S0````!!#@B%
M`D$.#(<#00X0A@1!#A2#!48.E"!*#I1`1PZP0&4.N$!'#KQ`00[`0$<.Q$!%
M#LA`0@[,0$4.T$!)#K1`10ZX0$@.O$!!#L!`20ZP0$<.O$!&#L!`2PZP0$<.
MM$!!#KA`00Z\0$$.P$!.#K!`5@H.%$/##A!!Q@X,0<<."$'%#@1!"P`0````
M9`0``(R&__\%`````````/P```!X!```B(;__R<"````00X(A0)!#@R'`T$.
M$(8$00X4@P5&#I0@2@ZP(0)`#K@A0@Z\(4,.P"%)#K`A;0H.%$'##A!!Q@X,
M0<<."$'%#@1%"T,.O"%!#L`A1PZ\(4$.N"%+#KPA00[`(5<.L"%@#K@A00Z\
M(4$.P"%)#K`A2PZ\(4$.P"%/#K`A70Z\(4$.P"%+#K`A1PZ\(4$.P"%1#K`A
M3@ZT(4$.N"%$#KPA00[`(40.Q"%%#L@A0@[,(4@.T"%)#K@A1`Z\(4$.P"%)
M#K`A5PZX(40.O"%"#L`A2PZP(7X.N"%"#KPA00[`(4D.L"%4#KPA00[`(4D.
ML"$P````>`4``+B'__\X`````$$."(8"3`X,@P-##AA&#AQ!#B!)#A!.#@Q#
MPPX(0<8.!```@````*P%``#$A___=`$```!!#@B%`D$.#(<#00X0A@1!#A2#
M!48.E"!'#K`@=0Z\($$.P"!,#K`@?PZX($(.O"!!#L`@20ZP($\.O"!!#L`@
M20ZP(%H*#A1!PPX00<8.#$''#@A!Q0X$2PMC"@X40\,.$$'&#@Q!QPX(0<4.
M!$<+````/````#`&``#`B/___`,```!!#@B%`D$.#(<#00X0A@1,#A2#!4,.
M0`.X`PH.%$?##A!!Q@X,0<<."$'%#@1%"Q@```!P!@``@(S__V$`````30X@
M`D8*#@1%"P`H````C`8``-2,__\M`````$$."(,"3@X020X<00X@20X020X(
M0<,.!````(````"X!@``V(S___D`````00X(A0)!#@R'`T$.$(8$3`X4@P5#
M#D`"0@H.%$/##A!!Q@X,0<<."$'%#@1&"T,.2$$.3$$.4$D.0%0*#A1!PPX0
M0<8.#$''#@A!Q0X$2@M##DQ!#E!G#D1)#DA!#DQ'#E!!#E1"#EA"#EQ!#F!-
M#D```(P"```\!P``5(W__Q\'````00X(A0)!#@R'`T$.$(8$00X4@P51#I`"
M`M`.G`)!#J`"20Z0`E4.G`)!#J`"30Z0`D,.G`)!#J`"3PZ0`EX.G`)'#J`"
M00ZD`D(.J`)"#JP"00ZP`E`.D`("2`Z<`D$.H`)+#I`"?PZ<`D$.H`)'#IP"
M1`Z@`F@.I`)!#J@"2PZL`D<.L`)##K0"0@ZX`D(.O`)!#L`"20Z8`D4.G`)!
M#J`"20Z0`ED.F`)!#IP"1`Z@`DL.D`)'#IP"1`Z@`D8.I`)'#J@"2@ZL`D(.
ML`))#I`"6@H.%$/##A!!Q@X,0<<."$'%#@1("T,.G`)$#J`"2PZ0`@)9#IP"
M00Z@`E@.D`)+#I@"00Z<`D8.H`),#I`"2PZ<`D0.H`)+#I`"2`Z8`D<.G`)-
M#J`"20Z0`@)K#I0"00Z8`DH.G`)$#J`"00ZD`D(.J`)"#JP"00ZP`D\.D`)?
M#IP"00Z@`D$.I`)!#J@"1`ZL`D0.L`)$#K0"0@ZX`D(.O`)!#L`"20Z0`D,.
MF`)%#IP"00Z@`DD.D`)(#IP"1`Z@`EP.D`("1PZ<`D@.H`)+#I`"6PZ<`D$.
MH`)+#I`"3`H.F`)!#IP"1`Z@`D8.I`)2"T,.G`)!#J`"2`Z0`F$*#A1#PPX0
M0<8.#$''#@A!Q0X$30M;#I@"0@Z<`D0.H`))#I`"9@Z4`D0.F`)!#IP"10Z@
M`DT.E`)"#I@"2`Z<`D4.H`)-#I`"9PZ4`D\.F`)!#IP"00Z@`DT.E`)"#I@"
M2`Z<`D4.H`)5#J0"1PZH`D0.K`)$#K`"00ZT`D(.N`)"#KP"00[``DD.D`)@
M#IP"00Z@`DT.D`),#I@"1PZ<`DD.H`))#I`"````S````,P)``#DD?__'@(`
M``!!#@B%`D$.#(<#00X0A@1!#A2#!4X.,`)*#C1"#CA!#CQ!#D!+#C!'#C1'
M#CA%#CQ##D!.#C!2#C1"#CA!#CQ##D!+#C!<#C1!#CA%#CQ##D!)#C!##C1(
M#CA!#CQ##D!/#C1!#CA!#CQ##D!=#C!/#CA%#CQ!#D!,#C!B"@X40<,.$$'&
M#@Q!QPX(0<4.!$D+0PH./$8.0$@.,%P./$<.0$P+<PXX00X\0PY`20XP4PH.
M-$<..$(./$<.0$8+`'````"<"@``-)/__]$`````00X(AP)!#@R&`TP.$(,$
M0PXL40XP1@XL00XH0@XL00XP2PX@2@XL00XP6@X@=`H.$$'##@Q!Q@X(0<<.
M!$4+0PXD2`XH00XL00XP20X@5`H.$$/##@Q!Q@X(0<<.!$4+````1````!`+
M``"@<___2`(```!$#`$`21`%`G4`01`'`G5\1!`&`G5X$`,"=71,#P-U<`8#
M;P$*P0P!`$'#0<9!QT'%0PP$!$$+$````%@+``!)D___!``````````0````
M;`L``#F3__\$`````````!````"`"P``*9/__P0`````````$````)0+```9
MD___!`````````!`````J`L``!B3___?"P```$$."(4"00X,AP-!#A"&!$$.
M%(,%2`Z0`P/)"PH.%$'##A!!Q@X,0<<."$'%#@1!"P```!@```#L"P``M)[_
M_U``````30X<0@X@`D`.!`!,````"`P``.B>___7`0```$$."(4"00X,AP-!
M#A"&!$P.%(,%0PXP`RP!"@X40<,.$$'&#@Q!QPX(0<4.!$8+`D`.-$0..$<.
M/$$.0%(.,#P```!8#```>*#__Q`"````2PX(A0)!#@R'`T$.$(8$00X4@P5#
M#C`#*P$*#A1!PPX00<8.#$''#@A!Q0X$4`L@````F`P``$BB__\I`````$T.
M$$8.%$0.&$0.'$0.($D.!``8````O`P``%2B__\5`````$$."$$.!$T.$```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
ML",``&`C```!````\P(```$```#^`@``'0```(H$```,`````"````T```"X
M4```&0```-B]```;````!````!H```#<O0``'`````0```#U_O]O-`(```4`
M``!H"0``!@```(@#```*````K00```L````0````%0`````````#````Z+X`
M``(````(````%````!$````7````I!$``!$```!T#P``$@```#`"```3````
M"````!X````(````^___;P$```C^__]OU`X``/___V\!````\/__;Q8.``#Z
M__]O!0``````````````````````````````````````````````````````
M``#@O0`````````````V(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!`(`````````3````*4$%2+G!M"@````#(8@``1T-#.B`H1TY5
M*2`Q,RXQ+C$@,C`R,S`T,CD``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N
M=2YB=6EL9"UI9``N;F]T92YG;G4N<')O<&5R='D`+FYO=&4N04))+71A9P`N
M9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E
M<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N
M<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF
M:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=```
M```````````````````````````````````````````````````````+````
M`0````(```"T`0``M`$``!,```````````````$`````````$P````<````"
M````R`$``,@!```D```````````````$`````````"8````'`````@```.P!
M``#L`0``*```````````````!``````````Y````!P````(````4`@``%`(`
M`"````````````````0`````````1P```/;__V\"````-`(``#0"``!4`0``
M!@`````````$````!````%$````+`````@```(@#``"(`P``X`4```<````!
M````!````!````!9`````P````(```!H"0``:`D``*T$``````````````$`
M````````80```/___V\"````%@X``!8.``"\````!@`````````"`````@``
M`&X```#^__]O`@```-0.``#4#@``H`````<````!````!`````````!]````
M"0````(```!T#P``=`\``#`"```&``````````0````(````A@````D```!"
M````I!$``*01```(````!@```!8````$````"````(\````!````!@`````@
M````(```(```````````````!`````````"*`````0````8````@(```("``
M`"```````````````!`````$````E0````$````&````0"```$`@``!U,```
M```````````0`````````)L````!````!@```+A0``"X4```%```````````
M````!`````````"A`````0````(`````8````&```$I```````````````0`
M````````J0````$````"````3*```$R@```4`0`````````````$````````
M`+<````!`````@```&"A``!@H0``!`T`````````````!`````````#!````
M#@````,```#8O0``V+T```0```````````````0````$````S0````\````#
M````W+T``-R]```$```````````````$````!````-D````&`````P```."]
M``#@O0``"`$```<`````````!`````@```#B`````0````,```#HO@``Z+X`
M`!@!``````````````0````$````YP````$````#`````,````#````8````
M```````````$`````````.T````(`````P```!C````8P```%```````````
M````!`````````#R`````0```#``````````&,```!L```````````````$`
M```!`````0````,``````````````#/```#[```````````````!````````
!````
